# backend.users

> Proxy model for django logic.

Users entrypoints should be used within m2m integrations.


First migration is run with the default clean user admin, second with django-sso-app models linked and sso_id nullable,
third with actual configuration. 
